Contributing to scikit-survival
===============================

Pull requests are always welcome, and we appreciate any help you give.
There are many ways to contribute to scikit-survival:

- Reporting bugs.
- Writing new code, e.g. implementations of new algorithms, or examples.
- Fixing bugs.
- Improving documentation.
- Reviewing open pull requests.

For detailed instructions on how to get started, please see
the `contributing guidelines <https://scikit-survival.readthedocs.io/en/latest/contributing.html>`_.